@@ -20,12 +20,12 @@ export DEVSTACK_GATE_TEMPEST=1
 export DEVSTACK_GATE_TEMPEST_NOTESTS=1
 export KEEP_LOCALRC=1
 
-DEVSTACK_LOCAL_CONFIG+=$'\nenable_plugin heat git://git.openstack.org/openstack/heat'
-DEVSTACK_LOCAL_CONFIG+=$'\nenable_plugin ceilometer git://git.openstack.org/openstack/ceilometer'
-DEVSTACK_LOCAL_CONFIG+=$'\nenable_plugin aodh git://git.openstack.org/openstack/aodh'
-DEVSTACK_LOCAL_CONFIG+=$'\nenable_plugin mistral git://git.openstack.org/openstack/mistral'
-DEVSTACK_LOCAL_CONFIG+=$'\nenable_plugin vitrage git://git.openstack.org/openstack/vitrage'
-DEVSTACK_LOCAL_CONFIG+=$'\nenable_plugin vitrage-tempest-plugin git://git.openstack.org/openstack/vitrage-tempest-plugin'
+DEVSTACK_LOCAL_CONFIG+=$'\nenable_plugin heat https://git.openstack.org/openstack/heat'
+DEVSTACK_LOCAL_CONFIG+=$'\nenable_plugin ceilometer https://git.openstack.org/openstack/ceilometer'
+DEVSTACK_LOCAL_CONFIG+=$'\nenable_plugin aodh https://git.openstack.org/openstack/aodh'
+DEVSTACK_LOCAL_CONFIG+=$'\nenable_plugin mistral https://git.openstack.org/openstack/mistral'
+DEVSTACK_LOCAL_CONFIG+=$'\nenable_plugin vitrage https://git.openstack.org/openstack/vitrage'
+DEVSTACK_LOCAL_CONFIG+=$'\nenable_plugin vitrage-tempest-plugin https://git.openstack.org/openstack/vitrage-tempest-plugin'
 
 # we don't want swift
 DEVSTACK_LOCAL_CONFIG+=$'\ndisable_service s-account s-container s-object s-proxy'
@@ -38,6 +38,10 @@ DEVSTACK_LOCAL_CONFIG+="$(cat <<EOF
 notification_topics = notifications,vitrage_notifications
 notification_driver = messagingv2
 
+[notifications]
+versioned_notifications_topics = versioned_notifications,vitrage_notifications
+notification_driver = messagingv2
+
 [[post-config|\$NEUTRON_CONF]]
 [DEFAULT]
 notification_topics = notifications,vitrage_notifications
@@ -64,9 +68,6 @@ topics = notifications, vitrage_notifications
 [DEFAULT]
 notifiers = mistral,nova,webhook
 
-[static_physical]
-changes_interval = 5
-
 [datasources]
 snapshots_interval = 120
 EOF
