@@ -9,17 +9,22 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+import gc
 
 from vitrage.api.controllers.v1 import alarm
 from vitrage.api.controllers.v1 import event
 from vitrage.api.controllers.v1 import rca
 from vitrage.api.controllers.v1 import resource
+from vitrage.api.controllers.v1 import service
 from vitrage.api.controllers.v1 import template
 from vitrage.api.controllers.v1 import topology
 from vitrage.api.controllers.v1 import webhook
 
 
 class V1Controller(object):
+
+    gc.set_threshold(1, 1, 1)
+
     topology = topology.TopologyController()
     resources = resource.ResourcesController()
     alarm = alarm.AlarmsController()
@@ -27,3 +32,4 @@ class V1Controller(object):
     webhook = webhook.WebhookController()
     template = template.TemplateController()
     event = event.EventController()
+    service = service.ServiceController()
