@@ -12,25 +12,34 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-
+from oslo_log import log
 import sys
 
 from vitrage.cli import VITRAGE_TITLE
-from vitrage.entity_graph import get_graph_driver
+from vitrage.common.utils import spawn
 from vitrage.entity_graph.graph_init import VitrageGraphInit
+from vitrage.entity_graph.workers import GraphWorkersManager
 from vitrage import service
-from vitrage import storage
+
+LOG = log.getLogger(__name__)
 
 
 def main():
     """Main method of vitrage-graph"""
 
-    print(VITRAGE_TITLE)
     conf = service.prepare_service()
-    e_graph = get_graph_driver(conf)('Entity Graph')
-    db_connection = storage.get_connection_from_config(conf)
-    VitrageGraphInit(conf, e_graph, db_connection).run()
+    LOG.info(VITRAGE_TITLE)
 
+    workers = GraphWorkersManager(conf)
+    spawn(init, conf, workers)
+    workers.run()
+
+
+def init(conf, workers):
+    # Because fork duplicates the process memory.
+    # We should only create master process resources after workers are forked.
+    workers.wait_for_worker_start()
+    VitrageGraphInit(conf, workers).run()
 
 if __name__ == "__main__":
     sys.exit(main())
