@@ -51,16 +51,16 @@ class NovaNotifier(NotifierBase):
             if action:
                 action(data.get(VProps.ID), is_down)
             else:
-                LOG.warning('Unsupport datasource type %s for mark_down '
+                LOG.warning('Unsupported datasource type %s for mark_down '
                             'action', data.get(VProps.VITRAGE_TYPE))
 
     def _mark_host_down(self, host_id, is_down):
         try:
             LOG.info('Nova services.force_down - host id: %s, is_down: %s',
-                     str(host_id), str(is_down))
+                     host_id, is_down)
             response = self.client.services.force_down(
                 host_id, 'nova-compute', is_down)
-            LOG.info('RESPONSE %s', str(response.to_dict()))
+            LOG.info('RESPONSE %s', response.to_dict())
         except Exception:
             LOG.exception('Failed to services.force_down.')
 
@@ -68,8 +68,8 @@ class NovaNotifier(NotifierBase):
         state = InstanceState.ERROR if is_down else InstanceState.ACTIVE
         try:
             LOG.info('Nova servers.reset_state - server: %s, state: %s',
-                     str(server_id), str(state))
+                     server_id, state)
             response = self.client.servers.reset_state(server_id, state)
-            LOG.info('RESPONSE %s', str(response))
+            LOG.info('RESPONSE %s', response)
         except Exception:
             LOG.exception('Failed to execute servers.reset_state.')
