@@ -24,11 +24,19 @@ OPTS = [
     cfg.StrOpt('aodh_version', default='2', help='Aodh version'),
     cfg.StrOpt('ceilometer_version', default='2', help='Ceilometer version'),
     cfg.StrOpt('nova_version', default='2.11', help='Nova version'),
-    cfg.StrOpt('cinder_version', default='2', help='Cinder version'),
+    cfg.StrOpt('cinder_version', default='3', help='Cinder version'),
     cfg.StrOpt('glance_version', default='2', help='Glance version'),
     cfg.StrOpt('heat_version', default='1', help='Heat version'),
     cfg.StrOpt('mistral_version', default='2', help='Mistral version'),
-    cfg.StrOpt('gnocchi_version', default='1', help='Gnocchi version')
+    cfg.StrOpt('gnocchi_version', default='1', help='Gnocchi version'),
+    cfg.StrOpt('trove_version', default='1', help='Trove version'),
+    cfg.BoolOpt('use_nova_versioned_notifications',
+                default=True,
+                help='Indicates whether to use Nova versioned notifications.'
+                     'The default is True. If False, the deprecated Nova '
+                     'legacy notifications will be used.'
+                     'This flag must be set to False if notification_format '
+                     'is set to "unversioned" in nova.conf'),
 ]
 
 _client_modules = {
@@ -40,7 +48,8 @@ _client_modules = {
     'neutron': 'neutronclient.v2_0.client',
     'heat': 'heatclient.client',
     'mistral': 'mistralclient.api.v2.client',
-    'gnocchi': 'gnocchiclient.v1.client'
+    'gnocchi': 'gnocchiclient.v1.client',
+    'trove': 'troveclient.v1.client'
 }
 
 
@@ -103,6 +112,20 @@ def nova_client(conf):
         LOG.exception('Create Nova client - Got Exception.')
 
 
+def trove_client(conf):
+    """Get an instance of trove client"""
+    try:
+        tr_client = driver_module('trove')
+        client = tr_client.Client(
+            version=conf.trove_version,
+            session=keystone_client.get_session(conf),
+        )
+        LOG.info('Trove client created')
+        return client
+    except Exception:
+        LOG.exception('Create Trove client - Got Exception.')
+
+
 def cinder_client(conf):
     """Get an instance of cinder client"""
     try:
@@ -169,3 +192,16 @@ def mistral_client(conf):
         return client
     except Exception:
         LOG.exception('Create Mistral client - Got Exception.')
+
+
+def zaqar_client(conf):
+    """Get an instance of Zaqar client"""
+    try:
+        z_client = driver_module('zaqar')
+        client = z_client.Client(
+            session=keystone_client.get_session(conf),
+        )
+        LOG.info('Zaqar client created')
+        return client
+    except Exception:
+        LOG.exception('Create Zaqar client - Got Exception.')
