@@ -20,13 +20,11 @@ import oslo_messaging as messaging
 from oslo_messaging.rpc import dispatcher
 from osprofiler import profiler
 
+
 OPTS = [
     cfg.StrOpt('rpc_topic',
                default='rpcapiv1',
                help='The topic vitrage listens on'),
-    cfg.StrOpt('rpc_topic_collector',
-               default='rpc-collector',
-               help='The topic vitrage-collector listens on'),
 ]
 
 LOG = log.getLogger(__name__)
@@ -88,19 +86,11 @@ def get_client(transport, target, version_cap=None, serializer=None):
                                serializer=serializer)
 
 
-def get_default_server(conf, topic, endpoints):
-    transport = messaging.get_rpc_transport(conf)
-    target = messaging.Target(
-        topic=topic,
-        server=conf.oslo_messaging_rabbit.rabbit_hosts)
-    return get_server(target, endpoints, transport)
-
-
 def get_server(target, endpoints, transport, serializer=None):
     assert transport is not None
 
     if profiler:
-        LOG.info('profiler enabled for RPC server')
+        LOG.debug('profiler enabled for RPC server')
         serializer = ProfilerContextSerializer(serializer=serializer)
 
     access_policy = dispatcher.DefaultRPCAccessPolicy
