@@ -13,9 +13,7 @@
 # under the License.
 
 from datetime import datetime
-import json
 
-import cotyledon
 from oslo_log import log
 import oslo_messaging
 from oslo_utils import uuidutils
@@ -28,6 +26,7 @@ from pysnmp.proto.rfc1902 import Integer
 import sys
 
 from vitrage.common.constants import EventProperties
+from vitrage.coordination import service as coord
 from vitrage.datasources.transformer_base import extract_field_value
 from vitrage.messaging import get_transport
 from vitrage.snmp_parsing.properties import SnmpEventProperties as SEProps
@@ -36,16 +35,19 @@ from vitrage.utils.file import load_yaml_file
 LOG = log.getLogger(__name__)
 
 
-class SnmpParsingService(cotyledon.Service):
+class SnmpParsingService(coord.Service):
     RUN_FOREVER = 1
 
     def __init__(self, worker_id, conf):
-        super(SnmpParsingService, self).__init__(worker_id)
+        super(SnmpParsingService, self).__init__(worker_id, conf)
         self.conf = conf
         self.listening_port = conf.snmp_parsing.snmp_listening_port
+        self.oid_mapping = \
+            load_yaml_file(self.conf.snmp_parsing.oid_mapping)
         self._init_oslo_notifier()
 
     def run(self):
+        super(SnmpParsingService, self).run()
         LOG.info("Vitrage SNMP Parsing Service - Starting...")
 
         transport_dispatcher = AsyncoreDispatcher()
@@ -72,6 +74,7 @@ class SnmpParsingService(cotyledon.Service):
             raise
 
     def terminate(self):
+        super(SnmpParsingService, self).terminate()
         LOG.info("Vitrage SNMP Parsing Service - Stopping...")
         LOG.info("Vitrage SNMP Parsing Service - Stopped!")
 
@@ -102,7 +105,7 @@ class SnmpParsingService(cotyledon.Service):
         binds_dict = {}
         for oid, val in var_binds:
             u_oid = self._convert_obj_to_unicode(oid)
-            binds_dict[u_oid] = int(val) if type(val) == Integer \
+            binds_dict[u_oid] = int(val) if isinstance(val, Integer) \
                 else self._convert_obj_to_unicode(val)
         return binds_dict
 
@@ -121,12 +124,10 @@ class SnmpParsingService(cotyledon.Service):
                 driver='messagingv2',
                 publisher_id=self.publisher,
                 topics=['vitrage_notifications'])
-        except Exception as e:
-            LOG.warning('Failed to initialize oslo notifier %s', str(e))
+        except Exception:
+            LOG.exception('Failed to initialize oslo notifier')
 
     def _send_snmp_to_queue(self, snmp_trap):
-        if str == type(snmp_trap):
-            snmp_trap = json.loads(snmp_trap)
         try:
             event_type = self._get_event_type(snmp_trap)
             if not event_type:
@@ -145,12 +146,11 @@ class SnmpParsingService(cotyledon.Service):
             LOG.warning('Snmp failed to post event. Exception: %s', e)
 
     def _get_event_type(self, snmp_trap):
-        yaml_file_content = load_yaml_file(self.conf.snmp_parsing.oid_mapping)
-        if not yaml_file_content:
+        if not self.oid_mapping:
             LOG.warning('No snmp trap is configured!')
             return None
 
-        for mapping_info in yaml_file_content:
+        for mapping_info in self.oid_mapping:
             system_oid = extract_field_value(mapping_info, SEProps.SYSTEM_OID)
             conf_system = extract_field_value(mapping_info, SEProps.SYSTEM)
             if conf_system == extract_field_value(snmp_trap, system_oid):
