@@ -19,6 +19,8 @@ from oslo_utils import timeutils
 # noinspection PyPackageRequirements
 from oslotest import base
 import sys
+
+from testtools import matchers
 from testtools.matchers import HasLength
 
 
@@ -28,14 +30,14 @@ IsEmpty = lambda: HasLength(0)
 class BaseTest(base.BaseTestCase):
     """Test case base class for all unit tests."""
 
-    def assert_list_equal(self, l1, l2):
+    def assert_list_equal(self, l1, l2, message=None):
         if tuple(sys.version_info)[0:2] < (2, 7):
             # for python 2.6 compatibility
-            self.assertEqual(l1, l2)
+            self.assertEqual(l1, l2, message)
         else:
-            super(BaseTest, self).assertListEqual(l1, l2)
+            super(BaseTest, self).assertListEqual(l1, l2, message)
 
-    def assert_dict_equal(self, d1, d2, message):
+    def assert_dict_equal(self, d1, d2, message=None):
         if tuple(sys.version_info)[0:2] < (2, 7):
             # for python 2.6 compatibility
             self.assertEqual(d1, d2)
@@ -91,6 +93,10 @@ class BaseTest(base.BaseTestCase):
                                    dict(g2_edges.get(e_source_id)),
                                    "Edges of each graph are not equal")
 
+    def assert_starts_with(self, expected_prefix, observed_str, msg=None):
+        self.assertThat(observed_str,
+                        matchers.StartsWith(expected_prefix), msg)
+
     @staticmethod
     def path_get(project_file=None):
         root = os.path.abspath(os.path.join(os.path.dirname(__file__),
