@@ -88,6 +88,7 @@ def generate_sequential_events_list(generator_spec_list):
 
 def simple_instance_generators(host_num, vm_num,
                                snapshot_events=0, update_events=0,
+                               use_nova_versioned_format=True,
                                snap_vals=None, update_vals=None):
     """A function for returning vm event generators.
 
@@ -98,6 +99,8 @@ def simple_instance_generators(host_num, vm_num,
     :param vm_num: number of vms
     :param snapshot_events: number of snapshot events per instance
     :param update_events: number of update events per instance
+    :param use_nova_versioned_format: use the format of Nova versioned
+           notifications for the update events
     :param snap_vals: preset vals for ALL snapshot events
     :param update_vals: preset vals for ALL update events
     :return: generators for vm_num vms as specified
@@ -118,9 +121,13 @@ def simple_instance_generators(host_num, vm_num,
              tg.NUM_EVENTS: snapshot_events
              }
         )
+
+    dynamic_info = tg.DRIVER_INST_UPDATE_VERSIONED_D \
+        if use_nova_versioned_format else tg.DRIVER_INST_UPDATE_LEGACY_D
+
     if update_events:
         test_entity_spec_list.append(
-            {tg.DYNAMIC_INFO_FKEY: tg.DRIVER_INST_UPDATE_D,
+            {tg.DYNAMIC_INFO_FKEY: dynamic_info,
              tg.STATIC_INFO_FKEY: None,
              tg.EXTERNAL_INFO_KEY: update_vals,
              tg.MAPPING_KEY: mapping,
@@ -128,6 +135,7 @@ def simple_instance_generators(host_num, vm_num,
              tg.NUM_EVENTS: update_events
              }
         )
+
     return tg.get_trace_generators(test_entity_spec_list)
 
 
@@ -195,6 +203,60 @@ def simple_zone_generators(zone_num, host_num, snapshot_events=0,
     return tg.get_trace_generators(test_entity_spec_list)
 
 
+def simple_trove_instance_generators(inst_num, snapshot_events=0,
+                                     snap_vals=None):
+    """A function for returning Trove instance generators.
+
+    Returns generators for a given number of Trove instances.
+
+    :param inst_num: number of instances
+    :return: generators for inst_num instances as specified
+    """
+
+    mapping = [('tr-instance-{0}'.format(idx), 'vm-{0}'.format(idx))
+               for idx in range(inst_num)]
+
+    test_entity_spec_list = [
+        {tg.DYNAMIC_INFO_FKEY: tg.DRIVER_TROVE_INSTANCE_SNAPSHOT_D,
+         tg.STATIC_INFO_FKEY: None,
+         tg.MAPPING_KEY: mapping,
+         tg.EXTERNAL_INFO_KEY: snap_vals,
+         tg.NAME_KEY: 'Database instance snapshot generator',
+         tg.NUM_EVENTS: snapshot_events
+         }
+    ]
+
+    return tg.get_trace_generators(test_entity_spec_list)
+
+
+def simple_trove_cluster_generators(clust_num, inst_num, snapshot_events=0,
+                                    snap_vals=None):
+    """A function for returning Trove cluster generators.
+
+    Returns generators for a given number of Trove clusters.
+
+    :param clust_num: number of clusters
+    :param inst_num: number of instances
+    :return: generators for clust_num clusters as specified
+    """
+
+    mapping = [('tr-cluster-{0}'.format(idx % clust_num),
+                'tr-inst-{0}'.format(idx))
+               for idx in range(inst_num)]
+
+    test_entity_spec_list = [
+        {tg.DYNAMIC_INFO_FKEY: tg.DRIVER_TROVE_CLUSTER_SNAPSHOT_D,
+         tg.STATIC_INFO_FKEY: None,
+         tg.MAPPING_KEY: mapping,
+         tg.EXTERNAL_INFO_KEY: snap_vals,
+         tg.NAME_KEY: 'Database cluster snapshot generator',
+         tg.NUM_EVENTS: snapshot_events
+         }
+    ]
+
+    return tg.get_trace_generators(test_entity_spec_list)
+
+
 def simple_volume_generators(volume_num, instance_num,
                              snapshot_events=0, update_events=0,
                              snap_vals=None, update_vals=None):
@@ -317,56 +379,6 @@ def simple_consistency_generators(consistency_num, update_events=0,
     return tg.get_trace_generators(test_entity_spec_list)
 
 
-def simple_switch_generators(switch_num, host_num,
-                             snapshot_events=0, snap_vals=None,
-                             update_events=0, update_vals=None):
-    """A function for returning switch events generators.
-
-    Returns generators for a given number of switches and hosts.
-    Hosts will be distributed across switches in round-robin style.
-    Switches are interconnected in a line.
-
-    :param update_vals:  number of events from update event
-    :param update_events: number of values from update event
-    :param switch_num: number of zones
-    :param host_num: number of hosts
-    :param snapshot_events: number of snapshot events per zone
-    :param snap_vals: preset values for ALL snapshot events
-    :return: generators for switch events as specified
-    """
-
-    mapping = [('host-{0}'.format(index), 'switch-{0}'.format(index %
-                                                              switch_num))
-               for index in range(host_num)
-               ]
-
-    test_entity_spec_list = []
-    if snapshot_events:
-        test_entity_spec_list.append(
-            {tg.DYNAMIC_INFO_FKEY: tg.DRIVER_SWITCH_SNAPSHOT_D,
-             tg.STATIC_INFO_FKEY: None,
-             tg.EXTERNAL_INFO_KEY: snap_vals,
-             tg.MAPPING_KEY: mapping,
-             tg.NAME_KEY: 'Switch snapshot generator',
-             tg.NUM_EVENTS: snapshot_events
-             }
-        )
-    if update_events:
-        update_vals = {} if not update_vals else update_vals
-        update_vals[DSProps.DATASOURCE_ACTION] = \
-            DatasourceAction.UPDATE
-        test_entity_spec_list.append(
-            {tg.DYNAMIC_INFO_FKEY: tg.DRIVER_SWITCH_SNAPSHOT_D,
-             tg.STATIC_INFO_FKEY: None,
-             tg.EXTERNAL_INFO_KEY: update_vals,
-             tg.MAPPING_KEY: mapping,
-             tg.NAME_KEY: 'Switch update generator',
-             tg.NUM_EVENTS: update_events
-             }
-        )
-    return tg.get_trace_generators(test_entity_spec_list)
-
-
 def simple_static_generators(switch_num=2, host_num=10,
                              snapshot_events=0, snap_vals=None,
                              update_events=0, update_vals=None):
@@ -396,7 +408,7 @@ def simple_static_generators(switch_num=2, host_num=10,
             snap_vals = {}
         snap_vals.update({
             DSProps.DATASOURCE_ACTION: DatasourceAction.SNAPSHOT,
-            DSProps.SAMPLE_DATE: utcnow()})
+            DSProps.SAMPLE_DATE: str(utcnow())})
         test_entity_spec_list.append(
             {tg.DYNAMIC_INFO_FKEY: tg.DRIVER_STATIC_SNAPSHOT_D,
              tg.STATIC_INFO_FKEY: tg.DRIVER_STATIC_SNAPSHOT_S,
@@ -411,7 +423,7 @@ def simple_static_generators(switch_num=2, host_num=10,
             update_vals = {}
         update_vals.update({
             DSProps.DATASOURCE_ACTION: DatasourceAction.UPDATE,
-            DSProps.SAMPLE_DATE: utcnow()})
+            DSProps.SAMPLE_DATE: str(utcnow())})
         test_entity_spec_list.append(
             {tg.DYNAMIC_INFO_FKEY: tg.DRIVER_STATIC_SNAPSHOT_D,
              tg.STATIC_INFO_FKEY: None,
