@@ -53,12 +53,12 @@ DRIVER_COLLECTD_UPDATE_D = 'driver_collectd_update_dynamic.json'
 DRIVER_HOST_SNAPSHOT_D = 'driver_host_snapshot_dynamic.json'
 DRIVER_INST_SNAPSHOT_D = 'driver_inst_snapshot_dynamic.json'
 DRIVER_INST_SNAPSHOT_S = 'driver_inst_snapshot_static.json'
-DRIVER_INST_UPDATE_D = 'driver_inst_update_dynamic.json'
+DRIVER_INST_UPDATE_LEGACY_D = 'driver_inst_update_legacy_dynamic.json'
+DRIVER_INST_UPDATE_VERSIONED_D = 'driver_inst_update_versioned_dynamic.json'
 DRIVER_NAGIOS_SNAPSHOT_D = 'driver_nagios_snapshot_dynamic.json'
 DRIVER_NAGIOS_SNAPSHOT_S = 'driver_nagios_snapshot_static.json'
 DRIVER_PROMETHEUS_UPDATE_D = 'driver_prometheus_update_dynamic.json'
 DRIVER_ZABBIX_SNAPSHOT_D = 'driver_zabbix_snapshot_dynamic.json'
-DRIVER_SWITCH_SNAPSHOT_D = 'driver_switch_snapshot_dynamic.json'
 DRIVER_STATIC_SNAPSHOT_D = 'driver_static_snapshot_dynamic.json'
 DRIVER_STATIC_SNAPSHOT_S = 'driver_static_snapshot_static.json'
 DRIVER_VOLUME_UPDATE_D = 'driver_volume_update_dynamic.json'
@@ -68,7 +68,10 @@ DRIVER_STACK_SNAPSHOT_D = 'driver_stack_snapshot_dynamic.json'
 DRIVER_CONSISTENCY_UPDATE_D = 'driver_consistency_update_dynamic.json'
 DRIVER_ZONE_SNAPSHOT_D = 'driver_zone_snapshot_dynamic.json'
 DRIVER_KUBE_SNAPSHOT_D = 'driver_kubernetes_snapshot_dynamic.json'
-
+DRIVER_TROVE_INSTANCE_SNAPSHOT_D = \
+    'driver_trove_instance_snapshot_dynamic.json'
+DRIVER_TROVE_CLUSTER_SNAPSHOT_D = \
+    'driver_trove_cluster_snapshot_dynamic.json'
 
 # Mock transformer Specs (i.e., what the transformer outputs)
 MOCK_TRANSFORMER_PATH = '%s/mock_configurations/transformer' % \
@@ -79,7 +82,6 @@ TRANS_DOCTOR_UPDATE_D = 'transformer_doctor_update_dynamic.json'
 TRANS_COLLECTD_UPDATE_D = 'transformer_collectd_update_dynamic.json'
 TRANS_PROMETHEUS_UPDATE_D = 'transformer_prometheus_update_dynamic.json'
 TRANS_INST_SNAPSHOT_D = 'transformer_inst_snapshot_dynamic.json'
-TRANS_INST_SNAPSHOT_S = 'transformer_inst_snapshot_static.json'
 TRANS_HOST_SNAPSHOT_D = 'transformer_host_snapshot_dynamic.json'
 TRANS_HOST_SNAPSHOT_S = 'transformer_host_snapshot_static.json'
 TRANS_ZONE_SNAPSHOT_D = 'transformer_zone_snapshot_dynamic.json'
@@ -124,21 +126,25 @@ class EventTraceGenerator(object):
              DRIVER_COLLECTD_UPDATE_D: _get_simple_update_driver_values,
              DRIVER_KUBE_SNAPSHOT_D: _get_k8s_node_snapshot_driver_values,
              DRIVER_INST_SNAPSHOT_D: _get_vm_snapshot_driver_values,
-             DRIVER_INST_UPDATE_D: _get_vm_update_driver_values,
+             DRIVER_INST_UPDATE_LEGACY_D: _get_vm_update_legacy_driver_values,
+             DRIVER_INST_UPDATE_VERSIONED_D:
+                 _get_vm_update_versioned_driver_values,
              DRIVER_HOST_SNAPSHOT_D: _get_host_snapshot_driver_values,
              DRIVER_ZONE_SNAPSHOT_D: _get_zone_snapshot_driver_values,
              DRIVER_VOLUME_SNAPSHOT_D: _get_volume_snapshot_driver_values,
              DRIVER_VOLUME_UPDATE_D: _get_volume_update_driver_values,
              DRIVER_STACK_SNAPSHOT_D: _get_stack_snapshot_driver_values,
              DRIVER_STACK_UPDATE_D: _get_stack_update_driver_values,
-             DRIVER_SWITCH_SNAPSHOT_D: _get_switch_snapshot_driver_values,
              DRIVER_STATIC_SNAPSHOT_D: _get_static_snapshot_driver_values,
              DRIVER_NAGIOS_SNAPSHOT_D: _get_nagios_alarm_driver_values,
              DRIVER_ZABBIX_SNAPSHOT_D: _get_zabbix_alarm_driver_values,
              DRIVER_CONSISTENCY_UPDATE_D:
                  _get_consistency_update_driver_values,
              DRIVER_PROMETHEUS_UPDATE_D: _get_simple_update_driver_values,
-
+             DRIVER_TROVE_INSTANCE_SNAPSHOT_D:
+                _get_trove_instance_snapshot_driver_values,
+             DRIVER_TROVE_CLUSTER_SNAPSHOT_D:
+                _get_trove_cluster_snapshot_driver_values,
              TRANS_AODH_SNAPSHOT_D: _get_trans_aodh_alarm_snapshot_values,
              TRANS_AODH_UPDATE_D: _get_trans_aodh_alarm_snapshot_values,
              TRANS_DOCTOR_UPDATE_D: _get_simple_trans_alarm_update_values,
@@ -489,7 +495,7 @@ def _get_trans_vm_snapshot_values(spec):
     return static_values
 
 
-def _get_vm_update_driver_values(spec):
+def _get_vm_update_legacy_driver_values(spec):
     """Generates the static driver values for each vm, for updates.
 
     :param spec: specification of event generation.
@@ -513,43 +519,32 @@ def _get_vm_update_driver_values(spec):
     return static_values
 
 
-def _get_switch_snapshot_driver_values(spec):
-    """Generates the static driver values for each zone.
+def _get_vm_update_versioned_driver_values(spec):
+    """Generates the static driver values for each vm, for updates.
 
     :param spec: specification of event generation.
     :type spec: dict
-    :return: list of static driver values for each zone.
+    :return: list of static driver values for each vm updates.
     :rtype: list
     """
 
-    host_switch_mapping = spec[MAPPING_KEY]
+    vm_host_mapping = spec[MAPPING_KEY]
     static_info = None
     if spec[STATIC_INFO_FKEY] is not None:
         static_info = utils.load_specs(spec[STATIC_INFO_FKEY])
-
     static_values = []
+    for vm_name, host_name in vm_host_mapping:
+        mapping = {
+            'nova_object.data': {
+                'host': host_name,
+                'display_name': vm_name
+            }
 
-    switches_info = {}
-    for host_name, switch_name in host_switch_mapping:
-        switch_info = switches_info.get(switch_name, [])
+        }
+        static_values.append(combine_data(
+            static_info, mapping, spec.get(EXTERNAL_INFO_KEY, None)
+        ))
 
-        relationship_info = {"type": NOVA_HOST_DATASOURCE,
-                             "name": host_name,
-                             "id": host_name,
-                             "relation_type": "contains"
-                             }
-
-        switch_info.append(relationship_info)
-        switches_info[switch_name] = switch_info
-
-    for host_name, switch_name in host_switch_mapping:
-        mapping = {'name': switch_name,
-                   'id': switch_name,
-                   'relationships': switches_info[switch_name]
-                   }
-        static_values.append(combine_data(static_info,
-                                          mapping,
-                                          spec.get(EXTERNAL_INFO_KEY, None)))
     return static_values
 
 
@@ -674,6 +669,40 @@ def _get_zabbix_alarm_driver_values(spec):
     return static_values
 
 
+def _get_trove_instance_snapshot_driver_values(spec):
+    inst_srv_mapping = spec[MAPPING_KEY]
+    static_info = None
+    if spec[STATIC_INFO_FKEY] is not None:
+        static_info = utils.load_specs(spec[STATIC_INFO_FKEY])
+    static_values = []
+
+    for inst_name, srv_name in inst_srv_mapping:
+        mapping = {'id': inst_name,
+                   'name': inst_name,
+                   'server_id': srv_name}
+        static_values.append(combine_data(
+            static_info, mapping, spec.get(EXTERNAL_INFO_KEY, None)))
+    return static_values
+
+
+def _get_trove_cluster_snapshot_driver_values(spec):
+    clust_inst_mapping = spec[MAPPING_KEY]
+    static_info = None
+    if spec[STATIC_INFO_FKEY] is not None:
+        static_info = utils.load_specs(spec[STATIC_INFO_FKEY])
+    static_values = []
+
+    for clust_name, inst_name in clust_inst_mapping:
+        mapping = {'id': clust_name,
+                   'name': clust_name,
+                   'instances': [
+                       {'id': inst_name, 'name': inst_name}
+                   ]}
+        static_values.append(combine_data(
+            static_info, mapping, spec.get(EXTERNAL_INFO_KEY, None)))
+    return static_values
+
+
 def _get_trans_host_snapshot_values(spec):
     """Generates the static driver values for each host.
 
